@@ -2,15 +2,15 @@ package Class::Usul::Schema;
 
 use namespace::autoclean;
 
-use Class::Usul::Constants   qw( AS_PARA AS_PASSWORD COMMA FAILED
-                                 FALSE NUL OK QUOTED_RE SPC TRUE );
+use Class::Usul::Constants   qw( AS_PARA AS_PASSWORD EXCEPTION_CLASS COMMA
+                                 FAILED FALSE NUL OK QUOTED_RE SPC TRUE );
 use Class::Usul::Crypt::Util qw( encrypt_for_config );
 use Class::Usul::Functions   qw( distname ensure_class_loaded io throw trim );
 use Class::Usul::Types       qw( ArrayRef Bool HashRef Maybe NonEmptySimpleStr
                                  PositiveInt SimpleStr Str );
 use Data::Record;
 use Try::Tiny;
-use Unexpected::Functions    qw( inflate_placeholders );
+use Unexpected::Functions    qw( inflate_placeholders Unspecified );
 use Moo;
 use Class::Usul::Options;
 
@@ -55,7 +55,7 @@ my $_rebuild_qdb = sub {
 };
 
 # Public attributes
-option 'database'       => is => 'ro',   isa => NonEmptySimpleStr,
+option 'database'       => is => 'lazy', isa => NonEmptySimpleStr,
    documentation        => 'The database to connect to',
    format               => 's', required => TRUE, trigger => $_rebuild_qdb;
 
@@ -77,11 +77,11 @@ option 'dry_run'        => is => 'ro',   isa => Bool, default => FALSE,
    documentation        => 'Prints out commands, do not execute them',
    short                => 'd';
 
-option 'preversion'     => is => 'ro',   isa => Str, default => NUL,
+option 'preversion'     => is => 'rwp',  isa => Str, default => NUL,
    documentation        => 'Previous schema version',
    format               => 's';
 
-option 'rdbms'          => is => 'ro',   isa => ArrayRef, autosplit => COMMA,
+option 'rdbms'          => is => 'lazy', isa => ArrayRef, autosplit => COMMA,
    documentation        => 'List of supported RDBMSs',
    default              => sub { [ qw( MySQL SQLite PostgreSQL ) ] },
    format               => 's@';
@@ -203,37 +203,6 @@ my $_create_ddl = sub {
    return;
 };
 
-my $_deploy_and_populate = sub {
-   my ($self, $schema_class, $dir) = @_; my $res; my $schema;
-
-   if ($self->dry_run) {
-      $self->output( "Would deploy schema ${schema_class} from ${dir}" );
-      $self->dumper( map { $_->basename }
-                     $dir->filter( sub { m{ \.sql \z }mx } )->all_files );
-   }
-   else {
-      $self->info( "Deploying schema ${schema_class} and populating" );
-      $schema = $schema_class->connect
-         ( $self->dsn, $self->user, $self->password, $self->$_connect_attr );
-      $schema->storage->ensure_connected;
-      $schema->deploy( $self->$_connect_attr, $dir );
-   }
-
-   my $dist  = distname $schema_class;
-   my $extn  = $self->config->extension;
-   my $re    = qr{ \A $dist [-] \d+ [-] (.*) \Q$extn\E \z }mx;
-   my $io    = io( $dir )->filter( sub { $_->filename =~ $re } );
-   my $split = Data::Record->new( { split => COMMA, unless => QUOTED_RE, } );
-
-   for my $path ($io->all_files) {
-      my ($class) = $path->filename =~ $re;
-
-      $res->{ $class } = $self->populate_class( $schema, $split, $class, $path);
-   }
-
-   return $res;
-};
-
 my $_execute_ddl = sub {
    my ($self, $admin_creds, $ddl, $opts) = @_; $admin_creds ||= {};
 
@@ -252,6 +221,47 @@ my $_execute_ddl = sub {
    return $self->run_cmd( $cmd, { out => 'stdout', %{ $opts // {} } } );
 };
 
+my $_list_population_classes = sub {
+   my ($self, $schema_class, $dir) = @_; my $res = [];
+
+   my $dist = distname $schema_class;
+   my $extn = $self->config->extension;
+   my $re   = qr{ \A $dist [-] \d+ [-] (.*) \Q$extn\E \z }mx;
+   my $io   = io( $dir )->filter( sub { $_->filename =~ $re } );
+
+   for my $path ($io->all_files) {
+      my ($class) = $path->filename =~ $re; push @{ $res }, [ $class, $path ];
+   }
+
+   return $res;
+};
+
+my $_deploy_and_populate = sub {
+   my ($self, $schema_class, $dir) = @_; my $res; my $schema;
+
+   if ($self->dry_run) {
+      $self->output( "Would deploy schema ${schema_class} from ${dir}" );
+      $self->dumper( map { $_->basename }
+                     $dir->filter( sub { m{ \.sql \z }mx } )->all_files );
+   }
+   else {
+      $self->info( "Deploying schema ${schema_class} and populating" );
+      $schema = $schema_class->connect
+         ( $self->dsn, $self->user, $self->password, $self->$_connect_attr );
+      $schema->storage->ensure_connected;
+      $schema->deploy( $self->$_connect_attr, $dir );
+   }
+
+   my $split = Data::Record->new( { split => COMMA, unless => QUOTED_RE, } );
+
+   for my $tuple (@{ $self->$_list_population_classes( $schema_class, $dir ) }){
+      $res->{ $tuple->[ 0 ] }
+         = $self->populate_class( $schema, $split, @{ $tuple } );
+   }
+
+   return $res;
+};
+
 # Public methods
 sub create_database : method {
    my $self     = shift;
@@ -418,6 +428,40 @@ sub populate_class {
    return $res;
 }
 
+sub repopulate_class : method {
+   my $self = shift;
+   my $dir = $self->config->sharedir;
+   my $class = $self->next_argv or throw Unspecified, [ 'class name' ];
+   my $schema_class = $self->schema_classes->{ $self->database };
+   my $tuples = $self->$_list_population_classes( $schema_class, $dir );
+   my $split = Data::Record->new( { split => COMMA, unless => QUOTED_RE, } );
+
+   ensure_class_loaded $schema_class;
+
+   my $schema = $schema_class->connect
+      ( $self->dsn, $self->user, $self->password, $self->$_connect_attr );
+
+   for my $tuple (grep { $_->[ 0 ] =~ m{ \A $class \z }imx } @{ $tuples }) {
+      my $data = $self->file->dataclass_schema->load( $tuple->[ 1 ] );
+      my $flds = [ split SPC, $data->{fields} ];
+      my @rows = map { [ map { $_unquote->( trim $_ ) }
+                         $split->records( $_ ) ] } @{ $data->{rows} };
+      my $rs   = $schema->resultset( $tuple->[ 0 ] );
+
+      for my $row (@rows) {
+         my $name = $row->[ 0 ]; my $type = $row->[ 1 ];
+
+         try {
+            $rs->create( { name => $name, type_class => $type } );
+            $self->info( "Create a ${type} type called ${name}" );
+         }
+         catch {};
+      }
+   }
+
+   return OK;
+}
+
 1;
 
 __END__
@@ -597,6 +641,12 @@ The unencrypted password used to connect to the database
 
 Populates one table from a single file
 
+=head2 repopulate_class - Reloads the given class from the initial load data
+
+   $self->repopulate_class;
+
+Specify the class to reload on the command line
+
 =head2 user
 
    $self->user;
